@@ -1,12 +1,12 @@
 <?php
+
 /**
  * @author    Andreas Fischer <bantu@phpbb.com>
  * @copyright 2014 Andreas Fischer
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib3\Crypt\Hash;
-use phpseclib3\Math\BigInteger;
+namespace phpseclib3\Tests;
 
 abstract class PhpseclibFunctionalTestCase extends PhpseclibTestCase
 {
