@@ -168,19 +168,19 @@ class HashTest extends PhpseclibTestCase
         ];
     }
 
-    /**
-     * @dataProvider hmacData
-     */
+    /** @dataProvider hmacData */
     public function testHMAC($hash, $key, $message, $result)
     {
         $this->assertHMACsTo($hash, $key, $message, $result);
     }
 
-    /**
-     * @dataProvider hmacData
-     */
+    /** @dataProvider hmacData */
     public function testHMAC96($hash, $key, $message, $result)
     {
+        if ($hash == 'aes_cmac') {
+            $this->assertTrue(true);
+            return;
+        }
         $this->assertHMACsTo($hash . '-96', $key, $message, substr($result, 0, 24));
     }
 
@@ -366,20 +366,41 @@ class HashTest extends PhpseclibTestCase
                 'This is a test using a larger than block-size key and a larger than block-size data. The key needs to be hashed before being used by the HMAC algorithm.',
                 'e37b6a775dc87dbaa4dfa9f96e5e3ffddebd71f8867289865df5a32d20cdc944b6022cac3c4982b10d5eeb55c3e4de15134676fb6de0446065c97440fa8c6a58'
             ],
+            // from https://www.rfc-editor.org/rfc/rfc4493.html#section-4
+            [
+                'aes_cmac',
+                pack('H*', '2b7e151628aed2a6abf7158809cf4f3c'),
+                '',
+                'bb1d6929e95937287fa37d129b756746',
+            ],
+            [
+                'aes_cmac',
+                pack('H*', '2b7e151628aed2a6abf7158809cf4f3c'),
+                pack('H*', '6bc1bee22e409f96e93d7e117393172a'),
+                '070a16b46b4d4144f79bdd9dd04a287c',
+            ],
+            [
+                'aes_cmac',
+                pack('H*', '2b7e151628aed2a6abf7158809cf4f3c'),
+                pack('H*', '6bc1bee22e409f96e93d7e117393172aae2d8a571e03ac9c9eb76fac45af8e5130c81c46a35ce411'),
+                'dfa66747de9ae63030ca32611497c827',
+            ],
+            [
+                'aes_cmac',
+                pack('H*', '2b7e151628aed2a6abf7158809cf4f3c'),
+                pack('H*', '6bc1bee22e409f96e93d7e117393172aae2d8a571e03ac9c9eb76fac45af8e5130c81c46a35ce411e5fbc1191a0a52eff69f2445df4f9b17ad2b417be66c3710'),
+                '51f0bebf7e3b9d92fc49741779363cfe',
+            ],
         ];
     }
 
-    /**
-     * @dataProvider hashData
-     */
+    /** @dataProvider hashData */
     public function testHash($hash, $message, $result)
     {
         $this->assertHashesTo($hash, $message, $result);
     }
 
-    /**
-     * @dataProvider hashData
-     */
+    /** @dataProvider hashData */
     public function testHash96($hash, $message, $result)
     {
         if (preg_match('#^sha3-\d+#', $hash) || preg_match('#^shake(?:128|256)-\d+#', $hash) || $hash === 'keccak256') {
@@ -417,9 +438,7 @@ class HashTest extends PhpseclibTestCase
         $this->assertSame($hash->getHash(), 'sha1');
     }
 
-    /**
-     * @dataProvider lengths
-     */
+    /** @dataProvider lengths */
     public function testGetLengthKnown($algorithm, $length)
     {
         $hash = new Hash($algorithm);
@@ -470,9 +489,7 @@ class HashTest extends PhpseclibTestCase
         ];
     }
 
-    /**
-     * @dataProvider UMACs
-     */
+    /** @dataProvider UMACs */
     public function testUMACs($message, $algo, $tag, $error)
     {
         $k = 'abcdefghijklmnop'; // A 16-byte UMAC key
